@@ -446,6 +446,18 @@ class SMTOtuApi
 	    return sprintf( self::CMD_set_log_level, $logLevel );
 	}
 	
+	const CMD_check_software_upgrade = 'OTU:SOFTWARE:CHECK "%s"';
+	
+	/**
+	 *
+	 * @param String $releaseFileName
+	 * @return string
+	 */
+	static function checkSoftwareUpgrade( $releaseFileName )
+	{
+		return sprintf( self::CMD_check_software_upgrade, $releaseFileName );
+	}	
+	
 	
 	const CMD_show_otu = 'OTU:LOCALIZE %s';
 	/**
@@ -1746,6 +1758,22 @@ class SMTOtuApi
     	return sprintf( self::CMD_restore_otu, $archiveFullPath );
     }
     
+    
+    /**
+     * Check OTU backup integrity
+     */
+    const CMD_check_otu_backup ='OTU:SMARTOTU:CHECKBackup "%s"';
+    
+    /**
+     * Check OTU backup integrity Command
+     *
+     * @return string command
+     */
+    static function getSmartOtuCheckBackupCommand( $archiveFullPath )
+    {
+    	return sprintf( self::CMD_check_otu_backup, $archiveFullPath );
+    }
+    
     //****************
     //* admin
     //***************     
@@ -1872,6 +1900,18 @@ class SMTOtuApi
     	return self::CMD_START_MANUAL_AUTOTEST;
     }
     
+    const CMD_GET_MONITORING_TEST_PORT = "OTU:TOPAZ:MON:PORT? %d";
+    /**
+     * Get Monitoring test port
+     *
+     * @param $testId integer [0 : 1024]
+     */
+    static function getMonitoringTestPortCommand( $testId )
+    {
+    	return sprintf( self::CMD_GET_MONITORING_TEST_PORT, $testId);
+    }
+    
+    
     const CMD_SET_FIREWALL = "OTU:SYSTEM:FIREWALL %s";
     const CMD_GET_FIREWALL = "OTU:SYSTEM:FIREWALL?";
     
@@ -2130,8 +2170,7 @@ class SMTOtuApi
     static function getSsh_Personalization()
     {
     	return self::CMD_Get_Ssh_Personalization;
-    }
-    
+    }        
 }
 
 
