@@ -210,12 +210,12 @@ class SMTMaintenanceService extends SMTService implements SMTIService
             
             if ( $snapshotName != NULL )
             {
-                $page = new SMTFileDownloadPage($snapshotName);            
-                $this->getContext()->getHttpResponse()->send( $page );            
+                $page = new SMTFileDownloadPage($snapshotName);
+                $this->getContext()->getHttpResponse()->send( $page );
             }
             else
             {
-                $e = new SMTIOException( SMTIOException::COULD_NOT_CREATE_SNAPSHOT );            
+                $e = new SMTIOException( SMTIOException::COULD_NOT_CREATE_SNAPSHOT );
                 $this->handleException($e);
             }    	
         }
@@ -225,38 +225,38 @@ class SMTMaintenanceService extends SMTService implements SMTIService
     	}
     }  
       
-    /**
-     * Request to download the given log file...
-     *
-     * @url GET /log
-     * @status 200
-     * @access protected
-     * @class SMTAccessControl {@requires install}
-     */
-    function downloadLogFile( $request_data )
-    {    	
-    	try
-    	{
-    	    $fileName = $request_data['fileName'];
+//     /**
+//      * Request to download the given log file...
+//      *
+//      * @url GET /log
+//      * @status 200
+//      * @access protected
+//      * @class SMTAccessControl {@requires install}
+//      */
+//     function downloadLogFile( $request_data )
+//     {    	
+//     	try
+//     	{
+//     	    $fileName = $request_data['fileName'];
     	    
-    	    $logFileName = SMTOtuDebug::retrieveLogFileName($fileName);
+//     	    $logFileName = SMTOtuDebug::retrieveLogFileName($fileName);
     	    
-        	if ( $logFileName != NULL )
-        	{
-        		$page = new SMTFileDownloadPage($logFileName);
-        		$this->getContext()->getHttpResponse()->send( $page );
-        	}
-        	else
-        	{
-        		$e = new SMTIOException( SMTIOException::FILE_NOT_FOUND );
-        		$this->handleException($e);
-        	}
-    	}
-    	catch( \Exception $e )
-    	{
-    		$this->handleException($e);
-    	}
-    }    
+//         	if ( $logFileName != NULL )
+//         	{
+//         		$page = new SMTFileDownloadPage($logFileName);
+//         		$this->getContext()->getHttpResponse()->send( $page );
+//         	}
+//         	else
+//         	{
+//         		$e = new SMTIOException( SMTIOException::FILE_NOT_FOUND );
+//         		$this->handleException($e);
+//         	}
+//     	}
+//     	catch( \Exception $e )
+//     	{
+//     		$this->handleException($e);
+//     	}
+//     }
 
     /**
      * Fetch log file names and log level
@@ -948,7 +948,7 @@ class SMTMaintenanceService extends SMTService implements SMTIService
     		$dto = SMTCertificateDto::getInstance( $request_data );
     		$certificateHelper = new SMTCertificate();
     		$certificateHelper->setContext( $this->getContext() );
-    		$certificateHelper->updateSshPublicKeys( $dto->getSshPublicKeys() );    		
+    		$certificateHelper->updateSshPublicKeys( $dto->getSshPublicKeys() );
     	}
     	catch( \Exception $e )
     	{
@@ -1034,19 +1034,19 @@ class SMTMaintenanceService extends SMTService implements SMTIService
         }        
     }
     
-    /**
-     *
-     * @url GET /test/log/{filename}
-     */
-    function testTestDownloadLogFile( $filename )
-    {
-        if ( SMTSmartOtuSettings::isDebugMode() )
-        {
-        	$url = '/maintenance/log?fileName='.$filename;
-        	$page = new SMTTestRestApiPage($url, null, 'GET');
-        	$this->getContext()->getHttpResponse()->send( $page );
-        }
-    }    
+//     /**
+//      *
+//      * @url GET /test/log/{filename}
+//      */
+//     function testTestDownloadLogFile( $filename )
+//     {
+//         if ( SMTSmartOtuSettings::isDebugMode() )
+//         {
+//         	$url = '/maintenance/log?fileName='.$filename;
+//         	$page = new SMTTestRestApiPage($url, null, 'GET');
+//         	$this->getContext()->getHttpResponse()->send( $page );
+//         }
+//     }
     
     
     /**
