@@ -1083,7 +1083,7 @@ class SMTLinkTestService extends SMTService implements SMTIService
     		{
     		    try 
     		    {
-    		        $kmlHelper->deleteKml($gpsFileName, $id);
+    		    	$kmlHelper->deleteKml($gpsFileName, $id);
     		    }
     		    catch( \Exception $ex)
     		    {
@@ -1137,16 +1137,18 @@ class SMTLinkTestService extends SMTService implements SMTIService
      * Request to download the given kml file...
      * Can be accessed outside SmartOTU: no security access
      *
-     * @url GET /kml
+     * @url GET /{id}/kml
+     * 
+     * @access protected
+     * @class SMTAccessControl {@requires user}
      */
-    function downloadKmlFile( $request_data )
+    function downloadKmlFile( $id )
     {
     	try
     	{
-    		$fileName = $request_data['fileName'];
-    		$kmlFileName = SMTGpsRoute::retrieveKmlFullPath($fileName);
+    		$kmlFileName= SMTGpsRoute::getKmlFileName($id);
     		 
-    		if ( $kmlFileName != NULL )
+    		if ( ($kmlFileName != NULL) && file_exists( $kmlFileName))
     		{
     			$page = new SMTFileDownloadPage($kmlFileName);
     			$this->getContext()->getHttpResponse()->send( $page );
