@@ -214,7 +214,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     {
         $traceName = $request_data['attachmentFileName'];
         $otdrTraceType = $request_data['traceStorageType'];
-        $newFilePath = $traceName;
+        $newFilePath = '';
         
         try
         {                    
@@ -230,16 +230,23 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
             {
                 $newFilePath = SMTOtdrTraceFileUtil::OTU_MEASURE_REF_DET_DIR.$traceName;
             }
-            else if ( SMTOtdrTraceType::OTU_ALARM_TRACE == $otdrTraceType )
+            else if ( (SMTOtdrTraceType::OTU_ALARM_TRACE == $otdrTraceType) || (SMTOtdrTraceType::OTU_SHORTACQ_ALARM_TRACE == $otdrTraceType) )
             {
                 $newFilePath = SMTOtdrTraceFileUtil::CUSTOM_SMARTOTU_ALARM_DIR.$traceName;
             }
             
             SMTLogger::getInstance()->trace( sprintf("Retrieve otdr trace file %s ",  $newFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
             
-            $page = new SMTOtdrTraceFileDownloadPage( $newFilePath, $otdrTraceType );
-
-            $this->getContext()->getHttpResponse()->send( $page );
+            if ( strlen( $newFilePath ) > 0 )
+            {
+            	$page = new SMTOtdrTraceFileDownloadPage( $newFilePath, $otdrTraceType );
+    	        $this->getContext()->getHttpResponse()->send( $page );
+            }
+            else
+            {
+            	$e = new SMTIOException( SMTIOException::FILE_NOT_FOUND );
+            	$this->handleException($e);
+            }
         }
         catch ( \Exception $e )
         {
@@ -391,6 +398,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     	{
     		//retrieve OTDR trace name
     		SMTLinkTest::checkTestId($testId);
+    		$portNumber = SMTLinkTest::getPortNumber($this->getContext()->getOtuSocket(), intval($testId));
     		
     		$alarmHelper = new SMTAlarm();
     		$alarmHelper->setContext( $this->getContext() );
@@ -398,7 +406,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     		
     		if ( $alarmDto != NULL )
     		{    		 
-    		    $traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $alarmDto->getDiscriminator() );
+    			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portNumber, $alarmDto->getDiscriminator() );
     		    SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
     		    $page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE );    		   
     		}
@@ -438,7 +446,8 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     
     		if ( $alarmDto != NULL )
     		{
-    			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmShortAcqTraceName( $testId, $alarmDto->getDiscriminator() );
+    			$portNumber = SMTLinkTest::getPortNumber($this->getContext()->getOtuSocket(), intval($testId));
+    			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmShortAcqTraceName( $testId, $portNumber, $alarmDto->getDiscriminator() );
     			if ( file_exists( $traceFilePath ) )
     			{
     			    SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
@@ -473,6 +482,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     	{
     		//retrieve OTDR trace name
     		SMTLinkTest::checkTestId($testId);
+    		$portNumber = SMTLinkTest::getPortNumber($this->getContext()->getOtuSocket(), intval($testId));
     
     		$alarmHelper = new SMTAlarm();
     		$alarmHelper->setContext( $this->getContext() );
@@ -480,7 +490,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     
     		if ( $alarmDto != NULL )
     		{
-    			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $alarmDto->getDiscriminator(), FALSE );
+    			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portNumber, $alarmDto->getDiscriminator(), FALSE );
     			SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
     			$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE );
     		}
@@ -496,7 +506,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
 	    				{
 	    					$alarmPeakByTestDiscriminator = SMTAlarmFactory::getDiscriminatorForOtdrTrace( $alarmDto->getTestId());
 	    					
-	    					$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $alarmPeakByTestDiscriminator, FALSE );
+	    					$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portNumber, $alarmPeakByTestDiscriminator, FALSE );
 	    					SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
 	    					$page = new SMTOtdrTracePage( $traceFilePath, SMTOtdrTraceType::OTU_ALARM_TRACE );
 	    					break;
@@ -533,8 +543,8 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
     	{
     		//retrieve OTDR trace name
     		SMTLinkTest::checkTestId($testId);
-    		         		    		
-    		$traceFilePath = SMTOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId );
+    		$portNumber = SMTLinkTest::getPortNumber($this->getContext()->getOtuSocket(), intval($testId));
+    		$traceFilePath = SMTOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId, $portNumber );
     		
     		SMTLogger::getInstance()->trace( sprintf("Retrieve last otdr monitoring acquisitiontrace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
     		
@@ -592,7 +602,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
                         		
                         		if ( $alarmDto != NULL )
                         		{    		 
-                        		    $traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $alarmDto->getDiscriminator() );
+                        			$traceFilePath = SMTOtdrTraceFileUtil::buildAlarmTraceName( $testId, $portid, $alarmDto->getDiscriminator() );
                         		    SMTLogger::getInstance()->trace( sprintf("Retrieve alarm trace file %s ",  $traceFilePath ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);  		   
                         		}
                         		else
@@ -602,7 +612,7 @@ class SMTOtdrAcqService extends SMTService implements SMTIService
                 	        	break;
             	        	case SMTOtdrTraceType::ACQ:
             	        	    $otdrTraceType = SMTOtdrTraceType::LAST_TEST_ACQUISITION_TRACE;
-            	        	    $traceFilePath = SMTOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId );
+            	        	    $traceFilePath = SMTOtdrTraceFileUtil::retrieveLastMonitoringAcquisitionTrace( $testId, $portid);
             	        		break;
             	        	default:
             	        	    throw new SMTLinkTestException( SMTLinkTestException::ERROR_MISSING_OTDR_TRACE, "invalid trace type ".$traceType );
