@@ -178,8 +178,8 @@ class SMTSwitchService extends SMTService implements SMTIService
     	    }
     	    else
     	    {
-    	        $this->getContext()->getLogger()->trace( sprintf("Remote host %s attempt to send autotest: forbidden!",$request->getClientIpAddress() ), SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
-    	    	throw new SMTAccessForbiddenRestException( MSG_ERROR_REMOTE_HOST_ATTEMPT_TO_SEND_AUTOTEST, "Host: ".$request->getClientIpAddress() );
+    	        $this->getContext()->getLogger()->trace( sprintf("Remote host %s attempt to send current port: forbidden!",$request->getClientIpAddress() ), SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
+    	    	throw new SMTAccessForbiddenRestException( MSG_ERROR_REMOTE_HOST_ATTEMPT_TO_SEND_DATA, "Host: ".$request->getClientIpAddress() );
     	    }    	   
     	}
     	catch ( \Exception $e )
