@@ -378,7 +378,7 @@ class SMTAlarm extends SMTServiceHelper
         	    //first, remove the old trace
         	    SMTOtdrTraceFileUtil::removeOTUAlarmTraceFromSmartOtu( $otuAlarm->getTestId(), $alarmDiscriminator );
         	    //copy the new files
-        		SMTOtdrTraceFileUtil::copyOtuAlarmTraceInSmartOtu( $otuAlarm->getLocalisationFileName(), $otuAlarm->getDetectionFileName(), $otuAlarm->getShortAcqFileName() ,$otuAlarm->getTestId(), $alarmDiscriminator );
+        	    SMTOtdrTraceFileUtil::copyOtuAlarmTraceInSmartOtu( $otuAlarm->getLocalisationFileName(), $otuAlarm->getDetectionFileName(), $otuAlarm->getShortAcqFileName() ,$otuAlarm->getTestId(), $otuAlarm->getOtuMonitoringTestPort(), $alarmDiscriminator );
         	}
         	
         	//start attenuation processing
@@ -462,7 +462,7 @@ class SMTAlarm extends SMTServiceHelper
     			//first, remove the old trace
     			SMTOtdrTraceFileUtil::removeOTUAlarmTraceFromSmartOtu( $otuAlarm->getTestId(), $alarmPeakByTestDiscriminator);
     			//copy the new files
-    			SMTOtdrTraceFileUtil::copyOtuAlarmTraceInSmartOtu( $otuAlarm->getLocalisationFileName(), $otuAlarm->getDetectionFileName(), $otuAlarm->getShortAcqFileName() ,$otuAlarm->getTestId(), $alarmPeakByTestDiscriminator);
+    			SMTOtdrTraceFileUtil::copyOtuAlarmTraceInSmartOtu( $otuAlarm->getLocalisationFileName(), $otuAlarm->getDetectionFileName(), $otuAlarm->getShortAcqFileName() ,$otuAlarm->getTestId(), $otuAlarm->getOtuMonitoringTestPort(), $alarmPeakByTestDiscriminator);
     		}
     		
     		//start peak processing
