@@ -47,14 +47,30 @@ class SMTLicence extends SMTServiceHelper
     const DEFAULT_LICENSE_NAME = "Licence.lic";    
     
     /**
-     * Copy and load license file in ISU.
+     * Remove software options from session (license is installed in ISU during upload)
      *
      * @param $filename The name of the license file
      *
      */
     function processLicense($fileName)
     {
-        $fullPath = SMTUtil::SMARTOTU_TEMP_DIR.$fileName;
+    	//license is installed in ISU during the upload to avoid to store file with invalid content on disk
+//     	$fullPath = SMTUtil::SMARTOTU_TEMP_DIR.$fileName;
+//     	$this->installLicense($fileName, $fullPath);
+    	
+    	//reset licence in session
+    	$this->resetSessionOptions();  
+    }
+    
+    /**
+     * Load license file in ISU.
+     *
+     * @param $filename The name of the license file
+     * @param $fullPath The full path name of the temporary file
+     * @throws Exception if process fails
+     */
+    function installLicense($fileName, $fullPath)
+    {
         $success = -1;
         
     	try
@@ -62,7 +78,7 @@ class SMTLicence extends SMTServiceHelper
     	    if ( file_exists( $fullPath) )
     	    {
     	        $command = sprintf(self::COPY_LICENSE_FILE_CMD, SMTUtil::escapeShellArgUtf8($fullPath) );
-    	        SMTLogger::getInstance()->trace( sprintf("command: %s.", $command ), SMTLogger::INFO);
+    	        SMTLogger::getInstance()->trace( sprintf("command: %s.", $command ), SMTLogger::DEBUG);
     	        
     	        // update ssh keys
     	        $value = exec ($command, $output, $success);
@@ -72,7 +88,7 @@ class SMTLicence extends SMTServiceHelper
     	        // 0 -> update license OK, otherwise KO
     	        if ($success !== 0)
     	        {
-    	        	throw new SMTIOException(SMTIOException::INVALID_FILE, "failed to copy uploaded license file");
+    	        	throw new SMTIOException(SMTIOException::INVALID_FILE, 'failed to copy uploaded license file');
     	        }    	            	        
     	        
         	    $socketManager = new SMTOtuSocketManager( $this->getContext() );
@@ -83,14 +99,11 @@ class SMTLicence extends SMTServiceHelper
         	        $socket->send( SMTOtuApi::setSsh_License_Option( self::DEFAULT_LICENSE_NAME ) );
         	    }
         	    catch(\Exception $ex)
-        	    {
+        	    {        	    	
         	        SMTLogger::getInstance()->traceException( $ex );
         	        throw new SMTIOException(SMTIOException::INVALID_FILE, sprintf("invalid license file %s",$fileName) );
         	    }
-        	    $socket->close();
-        	    
-        	    //reset licence in session
-        	    $this->resetSessionOptions();        	    
+        	    $socket->close();        	          	    
     	    }
     	    else
     	    {
@@ -99,9 +112,15 @@ class SMTLicence extends SMTServiceHelper
     	}
     	catch ( \Exception $e )
     	{
+    		//remove invalid file
+    		unlink('/acterna/user/harddisk/'.self::DEFAULT_LICENSE_NAME);
+    		
     		SMTLogger::getInstance()->traceException( $e );
     		throw $e;
     	}
+    	
+    	//always remove file after installation in ISU, because it can contain malicious stuff
+    	unlink('/acterna/user/harddisk/'.self::DEFAULT_LICENSE_NAME);
     }
     
     function resetSessionOptions()
