@@ -53,6 +53,8 @@ class SMTModule extends SMTServiceHelper
     const MODULE_COUNT = 3;
     const OTU_DTSS_FUNCTION = "COBRA";
     const OTU_DTS_FUNCTION  = "DTS";
+    const HIGH_RESOLUTION   = "-2";
+    const HIGH_DYNAMIC      = "-1";
     
     /**
      * Check module number: 0 or 1. Throw exception if the test fails.
@@ -408,6 +410,8 @@ class SMTModule extends SMTServiceHelper
     {
     	$resolutions = explode(",", $resolutionsString );
     	$resolutions = array_map ( "trim", $resolutions );
+    	//add high_dyn and high_res solutions:
+    	array_splice($resolutions,1,0, array(self::HIGH_DYNAMIC, self::HIGH_RESOLUTION));
     	return array_map( 'intval', $resolutions );
     }    
     
