@@ -37,6 +37,7 @@ use app\services\monitoring\SMTLinkTestDto;
 use app\services\monitoring\SMTMonitoringPeakDto;
 use app\settings\SMTSmartOtuThresholds;
 use app\serviceshelper\maintenance\SMTLicence;
+use app\parser\SMTOtuSocket;
 
 include_once( "phputf8/ascii.php" );
 
@@ -1616,6 +1617,17 @@ class SMTLinkTest extends SMTServiceHelper
         return SMTLinkTestDto::DEFAULT_LINK_TEST_NAME_PREFIX.$portNumber;
     }
     
+    /**
+     * Returns optical port number of the given test
+     *
+     * @param SMTOtuSocket $socket
+     * @param unknown $testId
+     */
+    public static function getPortNumber(SMTOtuSocket $socket,  $testId)
+    {
+    	return $socket->sendReceive( SMTOtuApi::getMonitoringTestPortCommand($testId));
+    }
+    
     /**
      * Create test data on the given port number
      * 
