@@ -50,8 +50,8 @@ class SMTOtdrTraceFileUtil
     const OTDR_TRACE_FILE_DET = "det";
     const OTDR_TRACE_FILE_LOC = "loc";
     const OTDR_TRACE_FILE_SHORTACQ = "loc_opti";
-    const OTU_TEST_RESULT_DET_FILE_NAME = "det_%s.sor";
-    const OTU_TEST_RESULT_LOC_FILE_NAME = "loc_%s.sor";
+    const OTU_TEST_RESULT_DET_FILE_NAME = "det_%s_port%s.sor";
+    const OTU_TEST_RESULT_LOC_FILE_NAME = "loc_%s_port%s.sor";
     
     /**
      * Directory for alarm files
@@ -64,7 +64,7 @@ class SMTOtdrTraceFileUtil
      * 
      * @var string
      */
-    const SMARTOTU_OTDR_ALARM_TRACE_FILE = "%s_trace_%s_%s.sor";
+    const SMARTOTU_OTDR_ALARM_TRACE_FILE = "%s_trace_%s_%s_port%s.sor";
     
     
     /**
@@ -72,7 +72,7 @@ class SMTOtdrTraceFileUtil
      * smtref + {portNumber}  //one test per link in SmartOTU mode
      * @var string
      */
-    const REF_TRACE_NAME = "smtref_%s.sor";
+    const REF_TRACE_NAME = "smtref_port%s.sor";
 
     /**
      * OTDR file bellcore extension
@@ -116,7 +116,7 @@ class SMTOtdrTraceFileUtil
         if ( $otdrTraceType == SMTOtdrTraceType::LAST_TEST_ACQUISITION_TRACE )
         {
         	//search on SmartOtu last acquisition directory
-        	$acquisitionTrace = self::getLastMonitoringTraceNameFromSmartOtu($testId);
+        	$acquisitionTrace = self::getLastMonitoringTraceNameFromSmartOtu($testId, $portNumber);
         }
         else if ( $otdrShortTraceName != NULL)
         {
@@ -217,11 +217,12 @@ class SMTOtdrTraceFileUtil
      * @param string $locTraceNameOnOTU alarm OTDR localisation trace name.
      * @param string $detTraceNameOnOTU alarm OTDR detection trace name.
      * @param int $testId The test identifier.
+     * @param int $portNumber The test optical port number
      * @param string $alarmDiscriminator The alarm discriminator. 
      *
      * @return string the OTDR alarm file name stored in SmartOTU directory.
      */
-    public static function copyOtuAlarmTraceInSmartOtu( $locTraceNameOnOTU, $detTraceNameOnOTU, $shortAcqFileNameOnOTU, $testId, $alarmDiscriminator )
+    public static function copyOtuAlarmTraceInSmartOtu( $locTraceNameOnOTU, $detTraceNameOnOTU, $shortAcqFileNameOnOTU, $testId, $portNumber,$alarmDiscriminator )
     {    
         $localisationTraceCopied = FALSE;
         
@@ -229,7 +230,7 @@ class SMTOtdrTraceFileUtil
     	$fullTraceNameOnOTU = ($locTraceNameOnOTU != NUll)? self::OTU_RESULT_LOC_DIR.$locTraceNameOnOTU : NULL;        
     	SMTLogger::getInstance()->trace( sprintf( "Start retrieving OTDR alarm trace: %s and %s ", $locTraceNameOnOTU, $detTraceNameOnOTU ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
     	    	
-    	$newAlarmTraceName = self::buildAlarmTraceName( $testId, $alarmDiscriminator );    	    	
+    	$newAlarmTraceName = self::buildAlarmTraceName( $testId, $portNumber, $alarmDiscriminator );    	    	
     	if ( $locTraceNameOnOTU != NUll && file_exists( $fullTraceNameOnOTU ) )
     	{
     	    SMTLogger::getInstance()->trace( sprintf( "Start copying OTDR alarm trace %s to %s ", $fullTraceNameOnOTU, $newAlarmTraceName ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
@@ -249,7 +250,7 @@ class SMTOtdrTraceFileUtil
     	$fullTraceNameOnOTU = ($shortAcqFileNameOnOTU != NUll)? self::OTU_RESULT_LOC_DIR.$shortAcqFileNameOnOTU : NULL;
     	if ( $shortAcqFileNameOnOTU != NULL && file_exists( $fullTraceNameOnOTU ) )
     	{
-    	    $newAlarmTraceName = self::buildAlarmShortAcqTraceName( $testId, $alarmDiscriminator );
+    		$newAlarmTraceName = self::buildAlarmShortAcqTraceName( $testId, $portNumber, $alarmDiscriminator );
     	    SMTLogger::getInstance()->trace( sprintf( "Start copying OTDR alarm trace %s to %s ", $fullTraceNameOnOTU, $newAlarmTraceName ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
     	    //don't throw exception for short acq
     	    if ( !copy( $fullTraceNameOnOTU, $newAlarmTraceName ) )
@@ -263,7 +264,7 @@ class SMTOtdrTraceFileUtil
         $fullTraceNameOnOTU = ( $detTraceNameOnOTU != NULL)? self::OTU_RESULT_DET_DIR.$detTraceNameOnOTU : NULL;
         if ( $detTraceNameOnOTU != NULL && file_exists( $fullTraceNameOnOTU ) )
         {
-            $newAlarmTraceName = self::buildAlarmTraceName( $testId, $alarmDiscriminator, false );
+        	$newAlarmTraceName = self::buildAlarmTraceName( $testId, $portNumber, $alarmDiscriminator, false );
             
             SMTLogger::getInstance()->trace( sprintf( "Start copying OTDR alarm trace %s to %s ", $fullTraceNameOnOTU, $newAlarmTraceName ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
             
@@ -285,29 +286,31 @@ class SMTOtdrTraceFileUtil
      * Returns alarm OTDR full trace file name
      *
      * @param int $testId
+     * @param string $portNumber
      * @param string $alarmDiscriminator the alarm discriminator
      * @param boolean $isLocalisation Whether the alarm otdr trace is the localization trace of the alarm. True by default.
      * @return string
      */
-    public static function buildAlarmTraceName( $testId, $alarmDiscriminator, $isLocalisation = TRUE )
+    public static function buildAlarmTraceName( $testId, $portNumber, $alarmDiscriminator, $isLocalisation = TRUE )
     {
         $alarmFileDiscriminator = self::filterNonAlphaNumericCharacters( $alarmDiscriminator );
         $traceType = ($isLocalisation)? self::OTDR_TRACE_FILE_LOC : self::OTDR_TRACE_FILE_DET;
-    	return self::createAlarmDirectoryIfNeeded().sprintf( self::SMARTOTU_OTDR_ALARM_TRACE_FILE, $traceType, $testId, $alarmFileDiscriminator );
+        return self::createAlarmDirectoryIfNeeded().sprintf( self::SMARTOTU_OTDR_ALARM_TRACE_FILE, $traceType, $testId, $alarmFileDiscriminator, $portNumber);
     }
     
     /**
      * Returns short acq alarm OTDR full trace file name
      *
      * @param int $testId
+     * @param string $portNumber
      * @param string $alarmDiscriminator the alarm discriminator
      * 
      * @return string
      */    
-    public static function buildAlarmShortAcqTraceName( $testId, $alarmDiscriminator )
+    public static function buildAlarmShortAcqTraceName( $testId, $portNumber, $alarmDiscriminator )
     {
     	$alarmFileDiscriminator = self::filterNonAlphaNumericCharacters( $alarmDiscriminator );
-    	return self::createAlarmDirectoryIfNeeded().sprintf( self::SMARTOTU_OTDR_ALARM_TRACE_FILE, self::OTDR_TRACE_FILE_SHORTACQ, $testId, $alarmFileDiscriminator );
+    	return self::createAlarmDirectoryIfNeeded().sprintf( self::SMARTOTU_OTDR_ALARM_TRACE_FILE, self::OTDR_TRACE_FILE_SHORTACQ, $testId, $alarmFileDiscriminator, $portNumber);
     }
     
     /**
@@ -318,10 +321,10 @@ class SMTOtdrTraceFileUtil
      * 
      * @return string the last monitoring OTDR acquisition trace file name stored in SmartOTU "lastacquisition" directory.
      */
-    public static function retrieveLastMonitoringAcquisitionTrace( $testId )
+    public static function retrieveLastMonitoringAcquisitionTrace( $testId, $portNumber)
     {
-        $newOtdrAcquisitionTraceName = "";
-    	$fullTraceNameOnOTU = self::buildLastMonitoringDetectionTraceNameOnOtu($testId);
+        $newOtdrAcquisitionTraceName = "";                        
+        $fullTraceNameOnOTU = self::buildLastMonitoringDetectionTraceNameOnOtu($testId, $portNumber);
     
     	try
     	{
@@ -334,7 +337,7 @@ class SMTOtdrTraceFileUtil
     		{
     			sleep( 1 );
     		}
-    		$newOtdrAcquisitionTraceName = self::copyOtuLastMonitoringDectectionAcquisitionTraceInSmartOtu($testId);
+    		$newOtdrAcquisitionTraceName = self::copyOtuLastMonitoringDectectionAcquisitionTraceInSmartOtu($testId, $portNumber);
     	}
     	catch( \Exception $e )
     	{
@@ -351,9 +354,9 @@ class SMTOtdrTraceFileUtil
      *
      * @return string the last monitoring OTDR acquisition trace file name stored in SmartOTU "lastacquisition" directory.
      */
-    private static function copyOtuLastMonitoringDectectionAcquisitionTraceInSmartOtu( $testId )
+    private static function copyOtuLastMonitoringDectectionAcquisitionTraceInSmartOtu( $testId, $portNumber)
     {    
-        $fullTraceNameOnOTU = self::buildLastMonitoringDetectionTraceNameOnOtu($testId);
+    	$fullTraceNameOnOTU = self::buildLastMonitoringDetectionTraceNameOnOtu($testId, $portNumber);
         
     	SMTLogger::getInstance()->trace( sprintf( "Start retrieving last monitoring OTDR acquisition trace %s ", $fullTraceNameOnOTU ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
     	 
@@ -364,7 +367,7 @@ class SMTOtdrTraceFileUtil
     	}
 
     	//backup OTDR file to the smartOTU directory to be used for monitoring test addition
-    	$newOtdrAcquisitionTraceName = SMTSessionDirectoryUtil::backupLastMonitoringTraceToSessionDirectory( $testId );
+    	$newOtdrAcquisitionTraceName = SMTSessionDirectoryUtil::backupLastMonitoringTraceToSessionDirectory( $testId, $portNumber);
     	
     	SMTLogger::getInstance()->trace( sprintf( "End copying last monitoring OTDR acquisition trace %s to %s ", $fullTraceNameOnOTU, $newOtdrAcquisitionTraceName ), SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);             
     
@@ -377,9 +380,9 @@ class SMTOtdrTraceFileUtil
      * @param int $testId
      * @return string
      */
-    public static function buildLastMonitoringDetectionTraceNameOnSmartOtu( $testId )
+    public static function buildLastMonitoringDetectionTraceNameOnSmartOtu( $testId, $portNumber)
     {
-        return SMTSessionDirectoryUtil::createSessionDirectoryIfNeeded().sprintf( self::OTU_TEST_RESULT_DET_FILE_NAME, $testId);
+    	return SMTSessionDirectoryUtil::createSessionDirectoryIfNeeded().sprintf( self::OTU_TEST_RESULT_DET_FILE_NAME, $testId, $portNumber);
     }
     
     /**
@@ -388,9 +391,9 @@ class SMTOtdrTraceFileUtil
      * @param int $testId
      * @return string
      */
-    public static function buildLastMonitoringDetectionTraceNameOnOtu( $testId )
+    public static function buildLastMonitoringDetectionTraceNameOnOtu( $testId, $portNumber )
     {
-    	return self::OTU_TEST_RESULT_DET_DIR.sprintf( self::OTU_TEST_RESULT_DET_FILE_NAME, $testId);
+    	return self::OTU_TEST_RESULT_DET_DIR.sprintf( self::OTU_TEST_RESULT_DET_FILE_NAME, $testId, $portNumber);
     }
     
     /**
@@ -400,9 +403,9 @@ class SMTOtdrTraceFileUtil
      * @return string
      * @throws SMTIOException if file was not found
      */
-    public static function getLastMonitoringTraceNameFromSmartOtu( $testId )
+    public static function getLastMonitoringTraceNameFromSmartOtu( $testId, $portNumber)
     {                
-        $traceFilePath = self::buildLastMonitoringDetectionTraceNameOnSmartOtu($testId);
+    	$traceFilePath = self::buildLastMonitoringDetectionTraceNameOnSmartOtu($testId, $portNumber);
         if ( !file_exists( $traceFilePath ) )
         {
             throw new SMTIOException( SMTIOException::FILE_NOT_FOUND, $traceFilePath );
@@ -419,33 +422,25 @@ class SMTOtdrTraceFileUtil
      */
     public static function removeOTUAlarmTraceFromSmartOtu( $testId, $alarmDiscriminator )
     {
-        $fileToRemove = self::buildAlarmTraceName( $testId, $alarmDiscriminator );
-        
-        SMTLogger::getInstance()->trace("Start remove detection OTDR alarm trace: ".$fileToRemove, SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
-        
-        if ( file_exists( $fileToRemove ) )
-        {
-            if ( !unlink( $fileToRemove ) )
-            {
-                SMTLogger::getInstance()->trace("Couldn't remove OTDR localisation trace: ".$fileToRemove, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
-            }
-        }
+    	foreach ( glob( self::buildAlarmTraceName( $testId, "*", $alarmDiscriminator )) as $fileToRemove )
+    	{
+    		SMTLogger::getInstance()->trace("Start remove localisation OTDR alarm trace: ".$fileToRemove, SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
+    		if ( !unlink( $fileToRemove ) )
+    		{
+    			SMTLogger::getInstance()->trace("Couldn't remove OTDR localisation trace: ".$fileToRemove, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
+    		}
+    	}
 
-        $fileToRemove = self::buildAlarmTraceName( $testId, $alarmDiscriminator, FALSE );
-        
-        SMTLogger::getInstance()->trace("Start remove localisation OTDR alarm trace: ".$fileToRemove, SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
-        
-        if ( file_exists( $fileToRemove ) )
+        foreach ( glob( self::buildAlarmTraceName( $testId, "*", $alarmDiscriminator, FALSE )) as $fileToRemove )
         {
+        	SMTLogger::getInstance()->trace("Start remove detection OTDR alarm trace: ".$fileToRemove, SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
         	if ( !unlink( $fileToRemove ) )
         	{
-        		SMTLogger::getInstance()->trace("Couldn't remove localisation OTDR alarm trace: ".$fileToRemove, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
+        		SMTLogger::getInstance()->trace("Couldn't remove detection OTDR alarm trace: ".$fileToRemove, SMTLogger::ERROR, __FILE__,__METHOD__,__LINE__);
         	}
         }    
 
-        $fileToRemove = self::buildAlarmShortAcqTraceName( $testId, $alarmDiscriminator );               
-        
-        if ( file_exists( $fileToRemove ) )
+        foreach ( glob( self::buildAlarmShortAcqTraceName( $testId, "*", $alarmDiscriminator )) as $fileToRemove )
         {
             SMTLogger::getInstance()->trace("Start remove short acq OTDR alarm trace: ".$fileToRemove, SMTLogger::DEBUG, __FILE__,__METHOD__,__LINE__);
         	if ( !unlink( $fileToRemove ) )
