@@ -21,11 +21,11 @@ $noUploadRunning = SMTUploadStatus::checkNoUploadRunning();
 if ( $noUploadRunning == TRUE )
 {
     //save kml in the target dir = same dir as gps segment file
-    $uploadStatus = upload_file( SMTGpsRoute::GPS_ROUTE_DIR );    
+    $uploadStatus = upload_file( SMTGpsRoute::GPS_ROUTE_DIR, 'checkKml' );    
     
     if ( $uploadStatus->getUploadErrorStatus() == SMTUploadStatusDto::NO_ERROR )
     {
-        SMTLogger::getInstance()->trace("Upload kml complete: ".$uploadStatus->getFileName(), SMTLogger::PINFO );
+        SMTLogger::getInstance()->trace("Upload kml complete: ".$uploadStatus->getFileName(), SMTLogger::INFO );
     }    
 }
 else
@@ -34,6 +34,9 @@ else
     $uploadStatus->setProgress( SMTUploadStatusDto::NO_UPLOAD );
     $uploadStatus->setUploadErrorStatus( SMTUploadStatusDto::UPLOAD_ALREADY_RUNNING );
     SMTLogger::getInstance()->trace("Upload already running...", SMTLogger::ERROR);
+    
+    // add error code 401 in case of upload failure
+    @header('Cache-Control: no-cache, must-revalidate', true, 401 ); 
 }
 
 $response = buildJsonResponse( $uploadStatus );
